# Generated by Django 5.2.11 on 2026-02-08 23:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('lex_app', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='AsOfTestModel',
        ),
        migrations.RemoveField(
            model_name='historicalasoftestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalasoftestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicalhistorydeletetestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalhistorydeletetestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicalrobustnesstestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalrobustnesstestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicalscenariotestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalscenariotestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicalschedtestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalschedtestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicaltemporaltestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltemporaltestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicaltestbitemporalmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltestbitemporalmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicaltimecmdtestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltimecmdtestmodel',
            name='history_object',
        ),
        migrations.RemoveField(
            model_name='historicaltracemodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltracemodel',
            name='history_object',
        ),
        migrations.DeleteModel(
            name='HistoryDeleteTestModel',
        ),
        migrations.RemoveField(
            model_name='metahistoricalasoftestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalasoftestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalhistorydeletetestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalhistorydeletetestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalrobustnesstestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalrobustnesstestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalscenariotestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalscenariotestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalschedtestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricalschedtestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltemporaltestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltemporaltestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltestbitemporalmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltestbitemporalmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltimecmdtestmodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltimecmdtestmodel',
            name='meta_history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltracemodel',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='metahistoricaltracemodel',
            name='meta_history_user',
        ),
        migrations.DeleteModel(
            name='RobustnessTestModel',
        ),
        migrations.DeleteModel(
            name='ScenarioTestModel',
        ),
        migrations.DeleteModel(
            name='SchedTestModel',
        ),
        migrations.DeleteModel(
            name='TemporalTestModel',
        ),
        migrations.DeleteModel(
            name='TestBitemporalModel',
        ),
        migrations.DeleteModel(
            name='TimeCmdTestModel',
        ),
        migrations.DeleteModel(
            name='TraceModel',
        ),
        migrations.DeleteModel(
            name='HistoricalAsOfTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalHistoryDeleteTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalRobustnessTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalScenarioTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalSchedTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalTemporalTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalTestBitemporalModel',
        ),
        migrations.DeleteModel(
            name='HistoricalTimeCmdTestModel',
        ),
        migrations.DeleteModel(
            name='HistoricalTraceModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalAsOfTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalHistoryDeleteTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalRobustnessTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalScenarioTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalSchedTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalTemporalTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalTestBitemporalModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalTimeCmdTestModel',
        ),
        migrations.DeleteModel(
            name='MetaHistoricalTraceModel',
        ),
    ]
